@@ -13,9 +13,10 @@ from mgzdb.schema import (
 LOGGER = logging.getLogger(__name__)
 ALLOWED = False
 ALLOWED_LADDERS = [131] #, 132]
-ALLOWED_RATE = 0
+ALLOWED_RATE = 1900
 SUPPORTED_DATASETS = [1]
-STARTING_SUPPORTED_DATASETS = [0, 1, 100]
+STARTING_SUPPORTED_DATASETS = [0, 1]
+STARTING_SUPPORTED_DATASETS = [0, 1, 100, 200]
 SAMPLE_INTERVAL = 30000
 
 
