@@ -36,6 +36,17 @@ class Person(BASE):
     id = Column(Integer, primary_key=True)
     name = Column(String, unique=True)
     country = Column(String)
+    aoeelo_id = Column(Integer)
+    aoeelo_rate = Column(Integer)
+    aoeelo_rank = Column(Integer)
+    esportsearnings_id = Column(Integer)
+    earnings = Column(Float)
+    first_name = Column(String)
+    last_name = Column(String)
+    portrait = Column(LargeBinary)
+    twitch = Column(String)
+    mixer = Column(String)
+    youtube = Column(String)
 
 
 class Event(BASE):
@@ -97,6 +108,7 @@ class Dataset(BASE):
     __tablename__ = 'datasets'
     id = Column(Integer, primary_key=True)
     name = Column(String)
+    short = Column(String)
 
 
 class Civilization(BASE):
@@ -289,6 +301,7 @@ class Match(BASE):
     version_id = Column(Integer, ForeignKey('versions.id'))
     game_version = Column(String)
     save_version = Column(Float)
+    log_version = Column(Integer)
     build = Column(String)
     dataset_id = Column(Integer, ForeignKey('datasets.id'), index=True)
     dataset_version = Column(String)
